package com.schoolinout.system.service;

import com.schoolinout.system.domain.AccessLog;
import com.schoolinout.system.domain.dto.InOutLogDto;
import com.schoolinout.system.domain.vo.InOutLogVo;

import java.util.List;

/**
 * 进出学校记录Service接口
 *
 * @author sakura
 * @date 2024-01-03
 */
public interface IAccessLogService {

    /**
     * 查询学生进出学校记录
     *
     * @param dto 查询条件
     * @return 进出学校记录
     */
    public List<InOutLogVo> queryStudentInOutLog(InOutLogDto dto);

    /**
     * 查询进出学校记录
     *
     * @param id 进出学校记录主键
     * @return 进出学校记录
     */
    public AccessLog selectAccessLogById(Long id);

    /**
     * 查询进出学校记录列表
     *
     * @param accessLog 进出学校记录
     * @return 进出学校记录集合
     */
    public List<AccessLog> selectAccessLogList(AccessLog accessLog);

    /**
     * 新增进出学校记录
     *
     * @param accessLog 进出学校记录
     * @return 结果
     */
    public int insertAccessLog(AccessLog accessLog);

    /**
     * 修改进出学校记录
     *
     * @param accessLog 进出学校记录
     * @return 结果
     */
    public int updateAccessLog(AccessLog accessLog);

    /**
     * 批量删除进出学校记录
     *
     * @param ids 需要删除的进出学校记录主键集合
     * @return 结果
     */
    public int deleteAccessLogByIds(Long[] ids);

    /**
     * 删除进出学校记录信息
     *
     * @param id 进出学校记录主键
     * @return 结果
     */
    public int deleteAccessLogById(Long id);
}
